@@ -213,7 +213,7 @@ def run():
         if vm.has_updated():
             print(f'发现新版本，开始更新({VersionManager.m_current_version})')
             vm.start_update()
-            print('更新完成')
+            print(f'更新完成({VersionManager.m_current_version})')
 
         webbrowser.open_new(f'http://localhost:{port}/')
 
